<?php
/**
 * @author    Climaxweb <climaxwebmaxell@gmail.com>
 * @link      https://www.climaxweb.net/maxbot/
 * @copyright 2019 Climaxweb
 */


if(!defined('ABSPATH')) exit();

/**
 * Create smwpcb_dialog_flow, smwpcb_topics_messages
 * and smwpcb_users_data_analytics_settings databases
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_create_db_dialog_flow_options')){

    function smwpcb_create_db_dialog_flow_options(){

      global $wpdb;
      $charset_collate = $wpdb->get_charset_collate();
      $table_name = $wpdb->prefix.'smwpcb_dialog_flow';
      if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
        $sql = "CREATE TABLE $table_name (
          id mediumint(9) NOT NULL AUTO_INCREMENT,
          topic_id mediumint(9) NOT NULL,
          topicflow longblob NOT NULL,
          PRIMARY KEY (id)
        ) $charset_collate;";
        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta( $sql );
      }
      $table_name = $wpdb->prefix.'smwpcb_topics_messages';
      if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
        $sql = "CREATE TABLE $table_name (
          id mediumint(9) NOT NULL AUTO_INCREMENT,
          topic_id mediumint(9) NOT NULL,
          firstmsg text NOT NULL,
          PRIMARY KEY (id)
        ) $charset_collate;";
        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta( $sql );
      }
      $table_name = $wpdb->prefix.'smwpcb_users_data_analytics_settings';
      if($wpdb->get_var("SHOW TABLES LIKE '$table_name'") != $table_name) {
        $sql = "CREATE TABLE $table_name (
          id mediumint(9) NOT NULL AUTO_INCREMENT,
          uniquekey varchar(15) NOT NULL,
          datausersarr text NOT NULL,
          PRIMARY KEY (id)
        ) $charset_collate;";
        require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
        dbDelta( $sql );
      }

    }

}

/**
 * Create new flow conversation with the topic_id
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_insert_new_dialog_flow')){

    function smwpcb_insert_new_dialog_flow($topic_id){
      global $wpdb;

      $table_name = $wpdb->prefix . 'smwpcb_dialog_flow';
      //base64_encode will never output anything that can be used for SQL injection.
      $wpdb->insert(
        $table_name,
        array(
          'topic_id' => $topic_id,
          'topicflow' => base64_encode(smwpcb_return_default_cp()),
        )
      );

    }

}

/**
 * Get a flow conversation using the topic_id.
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_retrieve_dialog_flow')){

    function smwpcb_retrieve_dialog_flow($topic_id){

      global $wpdb;
      $table_name = $wpdb->prefix . 'smwpcb_dialog_flow';
      return $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE topic_id = %d",$topic_id));

    }

}

/**
 * Get the collected user entry using uniquekey.
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_retrieve_users_data_analytics')){

    function smwpcb_retrieve_users_data_analytics($uniquekey){

      global $wpdb;
      $table_name = $wpdb->prefix . 'smwpcb_users_data_analytics_settings';
      $row_ret = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE uniquekey = %s",$uniquekey));
      return unserialize($row_ret->datausersarr);

    }

}

/**
 * Get all collected users entries.
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_retrieve_all_users_data_analytics')){

    function smwpcb_retrieve_all_users_data_analytics(){

      global $wpdb;
      $table_name = $wpdb->prefix . 'smwpcb_users_data_analytics_settings';
      return $wpdb->get_results("SELECT * FROM $table_name");

    }

}

/**
 * Get all collected users entries with order by id.
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_retrieve_users_data_analytics_results')){

    function smwpcb_retrieve_users_data_analytics_results(){

      global $wpdb;
      $table_name = $wpdb->prefix . 'smwpcb_users_data_analytics_settings';
      return $wpdb->get_results("SELECT * FROM $table_name ORDER BY id DESC");
    }

}

/**
 * Get all collected users entries with order by id between offset
 * and how much you want to display per page.
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_retrieve_users_data_analytics_results_btw2')){

    function smwpcb_retrieve_users_data_analytics_results_btw2($offset,$rowsperpage){

      global $wpdb;
      $table_name = $wpdb->prefix . 'smwpcb_users_data_analytics_settings';
      return $wpdb->get_results($wpdb->prepare("
	        SELECT * FROM $table_name 
	        ORDER BY id DESC 
	        LIMIT %d, %d ", $offset, $rowsperpage 
	    	));

    }

}

/**
 * Update collected users entries by using datausersarr 
 * and uniquekey.
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_update_users_data_analytics')){

    function smwpcb_update_users_data_analytics($datausersarr, $uniquekey){

      global $wpdb;
      $table_name  = $wpdb->prefix.'smwpcb_users_data_analytics_settings';
      $wpdb->query($wpdb->prepare("UPDATE $table_name
                SET datausersarr = %s
             WHERE uniquekey = %s",$datausersarr, $uniquekey)
      );

    }

}

/**
 * Add collected users entries by using datausersarr 
 * and uniquekey.
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_add_users_data_analytics')){

    function smwpcb_add_users_data_analytics($datausersarr, $uniquekey){

      global $wpdb;
      $table_name  = $wpdb->prefix.'smwpcb_users_data_analytics_settings';
      $wpdb->insert(
        $table_name,
        array(
          'datausersarr' => $datausersarr,
          'uniquekey' => $uniquekey,
        )
      );

    }

}

/**
 * Add collected users entries by using datausersarr 
 * and uniquekey.
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_update_dialog_flow')){

    function smwpcb_update_dialog_flow($dataForDB, $topic_id){

      global $wpdb;
      $table_name  = $wpdb->prefix.'smwpcb_dialog_flow';
      $wpdb->query($wpdb->prepare("UPDATE $table_name
                  SET topicflow = %s
               WHERE topic_id = %d",$dataForDB, $topic_id)
      );

    }

}

/**
 * Add and update messages blocks for a certain topic
 * with topic_id
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_add_update_topic_msg')){

    function smwpcb_add_update_topic_msg($dataArray, $topic_id){

      global $wpdb;
      $table_name  = $wpdb->prefix.'smwpcb_topics_messages';
      $query_results = $wpdb->get_results($wpdb->prepare("SELECT * FROM $table_name WHERE topic_id = %d",$topic_id));
      if(count($query_results) == 0) {
        $wpdb->insert(
            $table_name,
            array(
              'topic_id' => $topic_id,
              'firstmsg' => $dataArray,
            )
        );
      }else{
        $wpdb->query($wpdb->prepare("UPDATE $table_name
                  SET firstmsg = %s
               WHERE topic_id = %d",$dataArray, $topic_id)
        );
      }

    }

}

/**
 * Retrieve all blocks for a certain topic
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_retreive_all_subtopics')){

    function smwpcb_retreive_all_subtopics(){

      if(isset($_POST['topic_id'])){
      	
        global $wpdb;
        $topic_id = $_POST['topic_id'];
        if( $topic_id != 'closeDisc'){
          $table_name = $wpdb->prefix . 'smwpcb_topics_messages';
          $row_ret = $wpdb->get_row($wpdb->prepare("SELECT * FROM $table_name WHERE topic_id = %d",$topic_id));
          echo(json_encode(unserialize($row_ret->firstmsg)));
        }
        wp_die();
      }

    }

}


/**
 * after deleting a topic we should delete also
 * the rows with topic_id on smwpcb_dialog_flow
 * and smwpcb_topics_messages databases
 * @since: 1.0.0
 **/
if(!function_exists('smwpcb_delete_topic_from_db')){

    function smwpcb_delete_topic_from_db($topic_id){

      global $wpdb;
      $table_name  = $wpdb->prefix.'smwpcb_dialog_flow';
      $wpdb->query($wpdb->prepare("DELETE FROM $table_name WHERE topic_id = %d",$topic_id));
      $table_name  = $wpdb->prefix.'smwpcb_topics_messages';
      $wpdb->query($wpdb->prepare("DELETE FROM $table_name WHERE topic_id = %d",$topic_id));

    }

}



?>